@@ -398,10 +398,10 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	setFocusPolicy ( TQ_NoFocus );
 
 
-	
-
 	int padx= 550;
-	TQString txt[9] = {"Ho\nme","▲","Pg\nUp","◄"," ","►","End","▼","Pg\nDn"};
+	TQString txt[9] = { "Ho\nme", TQString::fromUtf8("▲"), "Pg\nUp",
+		TQString::fromUtf8("◄"), " ", TQString::fromUtf8("►"),
+		"End", TQString::fromUtf8("▼"), "Pg\nDn" };
 	TQString nump[9] = {"7","8","9","4","5","6","1","2","3"};
 	int val=0;
 	int nval[9] = {16,17,18,13,14,15,10,11,12};
@@ -412,8 +412,8 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 			v->move(padx+(b*35),sty+(a*35));
 			v->res();
 			v->setKeyCode(nval[val],cval[val]);
-			v->setText(TQString::fromUtf8(txt[val]));
-			v->setShiftText(TQString::fromUtf8(nump[val]));
+			v->setText(txt[val]);
+			v->setShiftText(nump[val]);
 			numl_keys.append(v);
 			connect ( v, TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
 			val++;
@@ -1826,7 +1826,7 @@ void KbdTray::mousePressEvent(TQMouseEvent *e)
 	}
 }
 
-
+#include "MainWidget.moc"
 
 
 
